@@ -3,9 +3,9 @@
 # SPDX-License-Identifier: EUPL-1.2
 
 from .base import ConfigParserBase
-from apacheconfig import make_loader
+from apacheconfig import make_loader  # type: ignore
 from threading import BoundedSemaphore
-from typing import Dict
+from typing import Any, Dict, cast
 
 max_concurrent_parsers = 1
 parser_semaphore = BoundedSemaphore(value=max_concurrent_parsers)
@@ -14,7 +14,7 @@ parser_semaphore = BoundedSemaphore(value=max_concurrent_parsers)
 class ApacheConfigParser(ConfigParserBase):
     __slots__ = ["content"]
 
-    def parse(self, content: str) -> Dict:
+    def parse(self, content: str) -> dict:
         """Return a dict with the parsed config.
 
         :return: Parsed configuration
@@ -25,13 +25,8 @@ class ApacheConfigParser(ConfigParserBase):
         if preparsed_content["content"] == "":
             raise ValueError("Cannot parse empty configuration")
 
-        # statsd configuration needs to be loaded before it can be used,
-        # so we can't measure the loading easily
-
         global parser_semaphore
         with make_loader() as loader, parser_semaphore:
-            config = loader.loads(content)
+            config = cast(Dict[str, Any], loader.loads(content))
 
-        if "statsd" in config:
-            self.statsd.get_counter().increment("parse")
         return config
