@@ -15,6 +15,7 @@ from typing import (
     Dict,
     Iterable,
     List,
+    Literal,
     Optional,
     Protocol,
     Set,
@@ -49,7 +50,13 @@ class UserInfo:
     user_uuid: UUID
     permissions: Dict[str, bool]
 
-    def __init__(self, user_uuid: UUID, permissions: Dict[str, bool]):
+    def __init__(
+        self,
+        user_uuid: UUID,
+        permissions: Dict[str, bool],
+        type: Literal["UserInfo"] = "UserInfo",
+    ):
+        self.type = type
         self.user_uuid = user_uuid
         self.permissions = permissions
 
@@ -228,6 +235,8 @@ def build_query_lookup_table(
 
 
 class DomainCommandContainer:
+    user_info: UserInfo
+
     def __init__(
         self,
         repository_factory: RepositoryFactory,
@@ -256,6 +265,8 @@ class DomainCommandContainer:
 
 
 class DomainQueryContainer:
+    user_info: UserInfo
+
     def __init__(
         self,
         repository_factory: RepositoryFactory,
